@@ -27,10 +27,7 @@
 #include <QVBoxLayout>
 #include <QSpacerItem>
 #include "src/UtilityFunction/functionclassifybutton.h"
-
-namespace Ui {
-class FunctionButtonWidget;
-}
+#include "src/Interface/ukuimenuinterface.h"
 
 class FunctionButtonWidget : public QWidget
 {
@@ -41,24 +38,30 @@ public:
     ~FunctionButtonWidget();
 
 private:
-    Ui::FunctionButtonWidget *ui;
-    QGridLayout* gridLayout=nullptr;
-    QVector<QAbstractButton*> vector;
-    QStringList icondisabledlist, iconlist,iconlightlist,functionnamelist;
+    QStringList m_categoryList;
 
 protected:
-    void initWidget();
+    /**
+     * @brief Initializes UI
+     */
+    void initUi();
 
 Q_SIGNALS:
     /**
-     * 向FunctionWidget界面发送功能分类按钮被点击信号
-     * @param btnname存放被点击按钮名称
+     * @brief Send button click signal to functionwidget interface
+     * @param btnname: Category button name
      */
     void sendFunctionBtnSignal(QString btnname);
 
-private Q_SLOTS:
-    void functionBtnClickedSlot();//功能分类按钮槽函数
-    void recvClassificationBtnList(QStringList list);//接收FunctionWidget界面分类按钮列表
+public Q_SLOTS:
+    /**
+     * @brief Respond to button click
+     */
+    void functionBtnClickedSlot();
+    /**
+     * @brief Receive function classification list
+     */
+    void recvClassificationBtnList();
 };
 
 #endif // FUNCTIONBUTTONWIDGET_H
