@@ -27,11 +27,19 @@
 
 UkuiMenuInterface::UkuiMenuInterface()
 {
+    QString path=QDir::homePath()+"/.config/ukui/ukui-menu.ini";
+    setting=new QSettings(path,QSettings::IniFormat);
 }
 
+QVector<QStringList> UkuiMenuInterface::appInfoVector=QVector<QStringList>();
+QVector<QString> UkuiMenuInterface::desktopfpVector=QVector<QString>();
+QVector<QStringList> UkuiMenuInterface::alphabeticVector=QVector<QStringList>();
+QVector<QStringList> UkuiMenuInterface::functionalVector=QVector<QStringList>();
+QVector<QString> UkuiMenuInterface::allAppVector=QVector<QString>();
+QStringList UkuiMenuInterface::androidDesktopfnList=QStringList();
+
 UkuiMenuInterface::~UkuiMenuInterface()
 {
-//    delete[] pAppInfo;
 }
 
 //文件递归查询
@@ -66,9 +74,7 @@ void UkuiMenuInterface::recursiveSearchFile(const QString& _filePath)
         else{
             //过滤后缀不是.desktop的文件
             QString filePathStr=fileInfo.filePath();
-            QFileInfo fileinfo(filePathStr);
-            QString file_suffix=fileinfo.suffix();
-            if(QString::compare(file_suffix,"desktop")!=0)
+            if(!filePathStr.endsWith(".desktop"))
             {
                 i++;
                 continue;
@@ -76,12 +82,33 @@ void UkuiMenuInterface::recursiveSearchFile(const QString& _filePath)
             QByteArray fpbyte=filePathStr.toLocal8Bit();
             char* filepath=fpbyte.data();
             g_key_file_load_from_file(keyfile,filepath,flags,error);
+            char* ret_1=g_key_file_get_locale_string(keyfile,"Desktop Entry","NoDisplay", nullptr, nullptr);
+            if(ret_1!=nullptr)
+            {
+                QString str=QString::fromLocal8Bit(ret_1);
+                if(str.contains("true"))
+                {
+                    i++;
+                    continue;
+                }
+            }
+            char* ret_2=g_key_file_get_locale_string(keyfile,"Desktop Entry","NotShowIn", nullptr, nullptr);
+            if(ret_2!=nullptr)
+            {
+                QString str=QString::fromLocal8Bit(ret_2);
+                if(str.contains("UKUI"))
+                {
+                    i++;
+                    continue;
+                }
+            }
+
             //过滤LXQt、KDE
             char* ret=g_key_file_get_locale_string(keyfile,"Desktop Entry","OnlyShowIn", nullptr, nullptr);
             if(ret!=nullptr)
             {
                 QString str=QString::fromLocal8Bit(ret);
-                if(QString::compare(str, "LXQt;")==0 || QString::compare(str, "KDE;")==0)
+                if(str.contains("LXQt") || str.contains("KDE"))
                 {
                     i++;
                     continue;
@@ -123,110 +150,71 @@ void UkuiMenuInterface::recursiveSearchFile(const QString& _filePath)
 QStringList UkuiMenuInterface::getDesktopFilePath()
 {
     filePathList.clear();
+    getAndroidApp();
     recursiveSearchFile("/usr/share/applications/");
 
-    filePathList.removeAll("/usr/share/applications/peony-folder-handler.desktop");
-    filePathList.removeAll("/usr/share/applications/gnome-software-local-file.desktop");
-    filePathList.removeAll("/usr/share/applications/org.gnome.Software.Editor.desktop");
-    filePathList.removeAll("/usr/share/applications/apport-gtk.desktop");
     filePathList.removeAll("/usr/share/applications/software-properties-livepatch.desktop");
-    filePathList.removeAll("/usr/share/applications/snap-handle-link.desktop");
-    filePathList.removeAll("/usr/share/applications/python3.7.desktop");
-    filePathList.removeAll("/usr/share/applications/rhythmbox-device.desktop");
-    filePathList.removeAll("/usr/share/applications/smplayer_enqueue.desktop");
-    filePathList.removeAll("/usr/share/applications/python2.7.desktop");
     filePathList.removeAll("/usr/share/applications/mate-color-select.desktop");
-    filePathList.removeAll("/usr/share/applications/shotwell-viewer.desktop");
-    filePathList.removeAll("/usr/share/applications/burner-nautilus.desktop");
-    filePathList.removeAll("/usr/share/applications/gnome-system-monitor-kde.desktop");
-    filePathList.removeAll("/usr/share/applications/hplj1020.desktop");
-    filePathList.removeAll("/usr/share/applications/ukui-network-scheme.desktop");
-    filePathList.removeAll("/usr/share/applications/ukui-panel.desktop");
-    filePathList.removeAll("/usr/share/applications/unity-activity-log-manager-panel.desktop");
     filePathList.removeAll("/usr/share/applications/blueman-adapters.desktop");
-    filePathList.removeAll("/usr/share/applications/fcitx-config-gtk3.desktop");
-    filePathList.removeAll("/usr/share/applications/im-config.desktop");
-    filePathList.removeAll("/usr/share/applications/fcitx-skin-installer.desktop");
-    filePathList.removeAll("/usr/share/applications/gcr-prompter.desktop");
-    filePathList.removeAll("/usr/share/applications/gcr-viewer.desktop");
-    filePathList.removeAll("/usr/share/applications/geoclue-demo-agent.desktop");
-    filePathList.removeAll("/usr/share/applications/gnome-disk-image-mounter.desktop");
-    filePathList.removeAll("/usr/share/applications/gnome-disk-image-writer.desktop");
-    filePathList.removeAll("/usr/share/applications/libreoffice-xsltfilter.desktop");
-    filePathList.removeAll("/usr/share/applications/peony-autorun-software.desktop");
-    filePathList.removeAll("/usr/share/applications/remmina-file.desktop");
-    filePathList.removeAll("/usr/share/applications/remmina-gnome.desktop");
-    filePathList.removeAll("/usr/share/applications/ukwm.desktop");
-    filePathList.removeAll("/usr/share/applications/nm-applet.desktop");
+    filePathList.removeAll("/usr/share/applications/blueman-manager.desktop");
     filePathList.removeAll("/usr/share/applications/mate-user-guide.desktop");
     filePathList.removeAll("/usr/share/applications/nm-connection-editor.desktop");
-    filePathList.removeAll("/usr/share/applications/pavucontrol-qt.desktop");
-    filePathList.removeAll("/usr/share/applications/ukui-volume-control.desktop");
-    filePathList.removeAll("/usr/share/applications/lximage-qt-screenshot.desktop");
-    filePathList.removeAll("/usr/share/applications/lximage-qt.desktop");
-    filePathList.removeAll("/usr/share/applications/appurl.desktop");
     filePathList.removeAll("/usr/share/applications/debian-uxterm.desktop");
     filePathList.removeAll("/usr/share/applications/debian-xterm.desktop");
-    filePathList.removeAll("/usr/share/applications/fcitx-ui-sogou-qimpanel.desktop");
+    filePathList.removeAll("/usr/share/applications/im-config.desktop");
     filePathList.removeAll("/usr/share/applications/fcitx.desktop");
     filePathList.removeAll("/usr/share/applications/fcitx-configtool.desktop");
-    filePathList.removeAll("/usr/share/applications/fcitx-qimpanel-configtool.desktop");
-    filePathList.removeAll("/usr/share/applications/peony-computer.desktop");
     filePathList.removeAll("/usr/share/applications/onboard-settings.desktop");
-    filePathList.removeAll("/usr/share/applications/xscreensaver-properties.desktop");
     filePathList.removeAll("/usr/share/applications/info.desktop");
-    filePathList.removeAll("/usr/share/applications/mate-about.desktop");
-    filePathList.removeAll("/usr/share/applications/pcmanfm-qt.desktop");
-    filePathList.removeAll("/usr/share/applications/qlipper.desktop");
-    filePathList.removeAll("/usr/share/applications/ktelnetservice5.desktop");
     filePathList.removeAll("/usr/share/applications/ukui-power-preferences.desktop");
     filePathList.removeAll("/usr/share/applications/ukui-power-statistics.desktop");
     filePathList.removeAll("/usr/share/applications/software-properties-drivers.desktop");
     filePathList.removeAll("/usr/share/applications/software-properties-gtk.desktop");
-    filePathList.removeAll("/usr/share/applications/galternatives.desktop");
     filePathList.removeAll("/usr/share/applications/gnome-session-properties.desktop");
-    filePathList.removeAll("/usr/share/applications/pcmanfm-qt-desktop-pref.desktop");
     filePathList.removeAll("/usr/share/applications/org.gnome.font-viewer.desktop");
-    filePathList.removeAll("/usr/share/applications/gucharmap.desktop");
     filePathList.removeAll("/usr/share/applications/xdiagnose.desktop");
     filePathList.removeAll("/usr/share/applications/gnome-language-selector.desktop");
-    filePathList.removeAll("/usr/share/applications/indicator-china-weather.desktop");
     filePathList.removeAll("/usr/share/applications/mate-notification-properties.desktop");
     filePathList.removeAll("/usr/share/applications/transmission-gtk.desktop");
     filePathList.removeAll("/usr/share/applications/mpv.desktop");
-    filePathList.removeAll("/usr/share/applications/atril.desktop");
-    filePathList.removeAll("/usr/share/applications/ukui-control-center.desktop");
-    filePathList.removeAll("/usr/share/applications/org.kde.kwalletmanager5.desktop");
     filePathList.removeAll("/usr/share/applications/system-config-printer.desktop");
-    filePathList.removeAll("/usr/share/applications/vim.desktop");
-    filePathList.removeAll("/usr/share/applications/kwalletmanager5-kwalletd.desktop");
     filePathList.removeAll("/usr/share/applications/org.gnome.DejaDup.desktop");
-    filePathList.removeAll("/usr/share/applications/redshift.desktop");
-    filePathList.removeAll("/usr/share/applications/python3.8.desktop");
     filePathList.removeAll("/usr/share/applications/yelp.desktop");
     filePathList.removeAll("/usr/share/applications/peony-computer.desktop");
     filePathList.removeAll("/usr/share/applications/peony-home.desktop");
     filePathList.removeAll("/usr/share/applications/peony-trash.desktop");
     filePathList.removeAll("/usr/share/applications/peony.desktop");
+
+    //v10
+    filePathList.removeAll("/usr/share/applications/mate-about.desktop");
+    filePathList.removeAll("/usr/share/applications/time.desktop");
+    filePathList.removeAll("/usr/share/applications/network.desktop");
+    filePathList.removeAll("/usr/share/applications/shares.desktop");
+    filePathList.removeAll("/usr/share/applications/mate-power-statistics.desktop");
+    filePathList.removeAll("/usr/share/applications/display-im6.desktop");
+    filePathList.removeAll("/usr/share/applications/display-im6.q16.desktop");
+    filePathList.removeAll("/usr/share/applications/openjdk-8-policytool.desktop");
+    filePathList.removeAll("/usr/share/applications/kylin-io-monitor.desktop");
+    filePathList.removeAll("/usr/share/applications/wps-office-uninstall.desktop");
+    filePathList.removeAll("/usr/share/applications/wps-office-misc.desktop");
+
     return filePathList;
 }
 
-QVector<QStringList> UkuiMenuInterface::appInfoVector=QVector<QStringList>();
-QVector<QString> UkuiMenuInterface::desktopfpVector=QVector<QString>();
-
 //创建应用信息容器
-QVector<QStringList> UkuiMenuInterface::create_appinfo_vector()
+QVector<QStringList> UkuiMenuInterface::createAppInfoVector()
 {
     desktopfpVector.clear();
     QVector<QStringList> appInfoVector;
     QVector<QStringList> vector;
+    vector.append(QStringList()<<"Android");//0安卓
     vector.append(QStringList()<<"Network");//1网络
     vector.append(QStringList()<<"Messaging");//2社交
     vector.append(QStringList()<<"Audio"<<"Video");//3影音
     vector.append(QStringList()<<"Development");//4开发
     vector.append(QStringList()<<"Graphics");//5图像
     vector.append(QStringList()<<"Game");//6游戏
-    vector.append(QStringList()<<"Office"<<"Calculator"<<"Spreadsheet"<<"Presentation"<<"WordProcessor");//7办公
+    vector.append(QStringList()<<"Office"<<"Calculator"<<"Spreadsheet"<<"Presentation"<<"WordProcessor"<<"TextEditor");//7办公
     vector.append(QStringList()<<"Education");//8教育
     vector.append(QStringList()<<"System"<<"Settings"<<"Security");//9系统
 
@@ -236,21 +224,21 @@ QVector<QStringList> UkuiMenuInterface::create_appinfo_vector()
     {
         QStringList appInfoList;
         QString desktopfp=desktopfpList.at(i);
-        QString icon=getAppIcon(desktopfpList.at(i));
         QString name=getAppName(desktopfpList.at(i));
-        QString exec=getAppExec(desktopfpList.at(i));
-        QString comment=getAppComment(desktopfpList.at(i));
+        QString englishName=getAppEnglishName(desktopfpList.at(i));
+        QString letter=getAppNameInitial(desktopfpList.at(i));
+        QString letters=getAppNameInitials(desktopfpList.at(i));
 
         desktopfpVector.append(desktopfp);
 
-        appInfoList<<desktopfp<<icon<<name<<exec<<comment;
+        appInfoList<<desktopfp<<name<<englishName<<letter<<letters;
         bool is_owned=false;
         for(int j=0;j<vector.size();j++)
         {
             if(matchingAppCategories(desktopfpList.at(i),vector.at(j)))//有对应分类
             {
                 is_owned=true;
-                appInfoList.append(QString::number(j+1));
+                appInfoList.append(QString::number(j));
             }
         }
         if(!is_owned)//该应用无对应分类
@@ -276,22 +264,6 @@ QString UkuiMenuInterface::getAppName(QString desktopfp)
     char* name=g_key_file_get_locale_string(keyfile,"Desktop Entry","Name", nullptr, nullptr);
     QString namestr=QString::fromLocal8Bit(name);
 
-//    QString namestr;
-//    QLocale cn;
-//    QString language=cn.languageToString(cn.language());
-//    if(QString::compare(language,"Chinese")==0)
-//    {
-//        char* name;
-//        name=g_key_file_get_locale_string(keyfile,"Desktop Entry","Name[zh_CN]", nullptr, nullptr);
-//        if(QString::fromLocal8Bit(name).isEmpty())
-//            name=g_key_file_get_locale_string(keyfile,"Desktop Entry","Name", nullptr, nullptr);
-//        namestr=QString::fromLocal8Bit(name);
-//    }
-//    else {
-//        char* name=g_key_file_get_locale_string(keyfile,"Desktop Entry","Name", nullptr, nullptr);
-//        namestr=QString::fromLocal8Bit(name);
-//    }
-
     g_key_file_free(keyfile);
     return namestr;
 }
@@ -387,141 +359,8 @@ QString UkuiMenuInterface::getAppType(QString desktopfp)
     return QString::fromLocal8Bit(type);
 }
 
-//根据应用名获取deskyop文件路径
-QString UkuiMenuInterface::getDesktopPathByAppName(QString appname)
+bool UkuiMenuInterface::cmpApp(QStringList &arg_1, QStringList &arg_2)
 {
-    QString desktopfp;
-    int index=0;
-    while(index<appInfoVector.size())
-    {
-        if(QString::compare(appInfoVector.at(index).at(2),appname)==0)
-        {
-            desktopfp=appInfoVector.at(index).at(0);
-            break;
-        }
-
-        index++;
-    }
-
-    return desktopfp;
-}
-
-//根据应用英文名获取desktop文件路径
-QString UkuiMenuInterface::getDesktopPathByAppEnglishName(QString appname)
-{
-    int i=0;
-    QString desktopfilepath;
-    QStringList desktopfpList=getDesktopFilePath();
-    for(i=0;i<desktopfpList.count();i++)
-    {
-        QString name=getAppEnglishName(desktopfpList.at(i));
-        if(QString::compare(name,appname)==0)
-        {
-            desktopfilepath=desktopfpList.at(i);
-        }
-    }
-    return desktopfilepath;
-}
-
-QVector<QStringList> UkuiMenuInterface::getAlphabeticClassification()
-{
-    QVector<QStringList> data;
-    QStringList appnameList;
-    appnameList.clear();
-    QStringList list[27];
-    int index=0;
-    while(index<appInfoVector.size())
-    {
-        QString appname=appInfoVector.at(index).at(2);
-        QString appnamepy=UkuiChineseLetter::getPinyins(appname);
-        char c=appnamepy.at(0).toLatin1();
-        switch (c) {
-        case 'A':
-            list[0].append(appname);
-            break;
-        case 'B':
-            list[1].append(appname);
-            break;
-        case 'C':
-            list[2].append(appname);
-            break;
-        case 'D':
-            list[3].append(appname);
-            break;
-        case 'E':
-            list[4].append(appname);
-            break;
-        case 'F':
-            list[5].append(appname);
-            break;
-        case 'G':
-            list[6].append(appname);
-            break;
-        case 'H':
-            list[7].append(appname);
-            break;
-        case 'I':
-            list[8].append(appname);
-            break;
-        case 'J':
-            list[9].append(appname);
-            break;
-        case 'K':
-            list[10].append(appname);
-            break;
-        case 'L':
-            list[11].append(appname);
-            break;
-        case 'M':
-            list[12].append(appname);
-            break;
-        case 'N':
-            list[13].append(appname);
-            break;
-        case 'O':
-            list[14].append(appname);
-            break;
-        case 'P':
-            list[15].append(appname);
-            break;
-        case 'Q':
-            list[16].append(appname);
-            break;
-        case 'R':
-            list[17].append(appname);
-            break;
-        case 'S':
-            list[18].append(appname);
-            break;
-        case 'T':
-            list[19].append(appname);
-            break;
-        case 'U':
-            list[20].append(appname);
-            break;
-        case 'V':
-            list[21].append(appname);
-            break;
-        case 'W':
-            list[22].append(appname);
-            break;
-        case 'X':
-            list[23].append(appname);
-            break;
-        case 'Y':
-            list[24].append(appname);
-            break;
-        case 'Z':
-            list[25].append(appname);
-            break;
-        default:
-            list[26].append(appname);
-            break;
-        }
-
-        index++;
-    }
-
     QLocale local;
     QString language=local.languageToString(local.language());
     if(QString::compare(language,"Chinese")==0)
@@ -529,34 +368,269 @@ QVector<QStringList> UkuiMenuInterface::getAlphabeticClassification()
     else
         local=QLocale(QLocale::English);
     QCollator collator(local);
+    if(collator.compare(arg_1.at(1),arg_2.at(1))<0)
+        return true;
+    else
+        return false;
+}
+
+QVector<QString> UkuiMenuInterface::getAllApp()
+{
+    QVector<QString> allAppVector;
+    QVector<QString> commonVector;
+    QVector<QStringList> appVector;
+    allAppVector.clear();
+    commonVector.clear();
+    appVector.clear();
+    commonVector=getCommonUseApp();
+    int index=0;
+    Q_FOREACH(QString desktopfp, desktopfpVector)
+    {
+        if(!commonVector.contains(desktopfp))
+            appVector.append(appInfoVector.at(index));
+        index++;
+    }
+    qSort(appVector.begin(),appVector.end(),cmpApp);
+    Q_FOREACH(QString desktopfp, commonVector)
+        allAppVector.append(desktopfp);
+
+    for(int index=0;index<appVector.size();index++)
+        allAppVector.append(appVector.at(index).at(0));
+
+    return allAppVector;
+}
+
+QVector<QString> UkuiMenuInterface::getCommonUseApp()
+{
+    QDateTime dt=QDateTime::currentDateTime();
+    int currentDateTime=dt.toTime_t();
+    int nDaySec=24*60*60;
+    setting->beginGroup("datetime");
+    QStringList dateTimeKeys=setting->allKeys();
+    QStringList timeOutKeys;
+    timeOutKeys.clear();
+    for(int i=0;i<dateTimeKeys.count();i++)
+    {
+        if((currentDateTime-setting->value(dateTimeKeys.at(i)).toInt())/nDaySec >= 4)
+        {
+            timeOutKeys.append(dateTimeKeys.at(i));
+        }
+
+    }
+    setting->endGroup();
+    for(int i=0;i<timeOutKeys.count();i++)
+    {
+        setting->beginGroup("application");
+        setting->remove(timeOutKeys.at(i));
+        setting->sync();
+        setting->endGroup();
+        setting->beginGroup("datetime");
+        setting->remove(timeOutKeys.at(i));
+        setting->sync();
+        setting->endGroup();
+    }
+
+    setting->beginGroup("lockapplication");
+    QStringList lockdesktopfnList=setting->allKeys();
+    for(int i=0;i<lockdesktopfnList.count()-1;i++)
+        for(int j=0;j<lockdesktopfnList.count()-1-i;j++)
+        {
+            int value_1=setting->value(lockdesktopfnList.at(j)).toInt();
+            int value_2=setting->value(lockdesktopfnList.at(j+1)).toInt();
+            if(value_1 > value_2)
+            {
+                QString tmp=lockdesktopfnList.at(j);
+                lockdesktopfnList.replace(j,lockdesktopfnList.at(j+1));
+                lockdesktopfnList.replace(j+1,tmp);
+
+            }
+        }
+    setting->endGroup();
+    setting->beginGroup("application");
+    QStringList desktopfnList=setting->allKeys();
+    for(int i=0;i<desktopfnList.count()-1;i++)
+        for(int j=0;j<desktopfnList.count()-1-i;j++)
+        {
+            int value_1=setting->value(desktopfnList.at(j)).toInt();
+            int value_2=setting->value(desktopfnList.at(j+1)).toInt();
+            if(value_1 < value_2)
+            {
+                QString tmp=desktopfnList.at(j);
+                desktopfnList.replace(j,desktopfnList.at(j+1));
+                desktopfnList.replace(j+1,tmp);
+
+            }
+        }
+    setting->endGroup();
+
+    QVector<QString> data;
+    Q_FOREACH(QString desktopfn,lockdesktopfnList)
+    {
+        QString desktopfp;
+        if(androidDesktopfnList.contains(desktopfn))
+            desktopfp=QString(QDir::homePath()+"/.local/share/applications/"+desktopfn);
+        else
+            desktopfp=QString("/usr/share/applications/"+desktopfn);
+        QFileInfo fileInfo(desktopfp);
+        if(!fileInfo.isFile())
+            continue;
+        data.append(desktopfp);
+    }
+    Q_FOREACH(QString desktopfn,desktopfnList)
+    {
+        QString desktopfp;
+        if(androidDesktopfnList.contains(desktopfn))
+            desktopfp=QString(QDir::homePath()+"/.local/share/applications/"+desktopfn);
+        else
+            desktopfp=QString("/usr/share/applications/"+desktopfn);
+        QFileInfo fileInfo(desktopfp);
+        if(!fileInfo.isFile() || !desktopfpVector.contains(desktopfp))
+            continue;
+        data.append(desktopfp);
+    }
+
+    return data;
+}
+
+QVector<QStringList> UkuiMenuInterface::getAlphabeticClassification()
+{
+    QVector<QStringList> data;
+    QStringList appnameList;
+    appnameList.clear();
+    QVector<QStringList> appVector[27];
+    int index=0;
+    while(index<appInfoVector.size())
+    {
+        QString appname=appInfoVector.at(index).at(1);
+        QString appnamepy=UkuiChineseLetter::getPinyins(appname);
+        char c=appnamepy.at(0).toLatin1();
+        switch (c) {
+        case 'A':
+            appVector[0].append(appInfoVector.at(index));
+            break;
+        case 'B':
+            appVector[1].append(appInfoVector.at(index));
+            break;
+        case 'C':
+            appVector[2].append(appInfoVector.at(index));
+            break;
+        case 'D':
+            appVector[3].append(appInfoVector.at(index));
+            break;
+        case 'E':
+            appVector[4].append(appInfoVector.at(index));
+            break;
+        case 'F':
+            appVector[5].append(appInfoVector.at(index));
+            break;
+        case 'G':
+            appVector[6].append(appInfoVector.at(index));
+            break;
+        case 'H':
+            appVector[7].append(appInfoVector.at(index));
+            break;
+        case 'I':
+            appVector[8].append(appInfoVector.at(index));
+            break;
+        case 'J':
+            appVector[9].append(appInfoVector.at(index));
+            break;
+        case 'K':
+            appVector[10].append(appInfoVector.at(index));
+            break;
+        case 'L':
+            appVector[11].append(appInfoVector.at(index));
+            break;
+        case 'M':
+            appVector[12].append(appInfoVector.at(index));
+            break;
+        case 'N':
+            appVector[13].append(appInfoVector.at(index));
+            break;
+        case 'O':
+            appVector[14].append(appInfoVector.at(index));
+            break;
+        case 'P':
+            appVector[15].append(appInfoVector.at(index));
+            break;
+        case 'Q':
+            appVector[16].append(appInfoVector.at(index));
+            break;
+        case 'R':
+            appVector[17].append(appInfoVector.at(index));
+            break;
+        case 'S':
+            appVector[18].append(appInfoVector.at(index));
+            break;
+        case 'T':
+            appVector[19].append(appInfoVector.at(index));
+            break;
+        case 'U':
+            appVector[20].append(appInfoVector.at(index));
+            break;
+        case 'V':
+            appVector[21].append(appInfoVector.at(index));
+            break;
+        case 'W':
+            appVector[22].append(appInfoVector.at(index));
+            break;
+        case 'X':
+            appVector[23].append(appInfoVector.at(index));
+            break;
+        case 'Y':
+            appVector[24].append(appInfoVector.at(index));
+            break;
+        case 'Z':
+            appVector[25].append(appInfoVector.at(index));
+            break;
+        default:
+            appVector[26].append(appInfoVector.at(index));
+            break;
+        }
+
+        index++;
+    }
 
     for(int i=0;i<26;i++)
     {
-        std::sort(list[i].begin(),list[i].end(),collator);
-        data.append(list[i]);
+        QStringList desktopfpList;
+        desktopfpList.clear();
+        qSort(appVector[i].begin(),appVector[i].end(),cmpApp);
+        for(int j=0;j<appVector[i].size();j++)
+            desktopfpList.append(appVector[i].at(j).at(0));
+        data.append(desktopfpList);
     }
 
-    QStringList otherList;
-    QStringList numberList;
-    for(int i=0;i<list[26].count();i++)
+     QVector<QStringList> otherVector;
+     QVector<QStringList> numberVector;
+    for(int i=0;i<appVector[26].count();i++)
     {
-        QChar c=list[26].at(i).at(0);
+        QString appname=appVector[26].at(i).at(2);
+        QChar c=appname.at(0);
         if(c<48 || (c>57 && c<65) || c>90)
-            otherList.append(list[26].at(i));
+            otherVector.append(appVector[26].at(i));
         else
-            numberList.append(list[26].at(i));
+            numberVector.append(appVector[26].at(i));
     }
-    std::sort(otherList.begin(),otherList.end(),collator);
-    std::sort(numberList.begin(),numberList.end(),collator);
-    data.append(otherList);
-    data.append(numberList);
+    qSort(otherVector.begin(),otherVector.end(),cmpApp);
+    qSort(numberVector.begin(),numberVector.end(),cmpApp);
+    QStringList otherfpList;
+    otherfpList.clear();
+    for(int i=0;i<otherVector.size();i++)
+        otherfpList.append(otherVector.at(i).at(0));
+    QStringList numberfpList;
+    numberfpList.clear();
+    for(int i=0;i<numberVector.size();i++)
+        numberfpList.append(numberVector.at(i).at(0));
+    data.append(otherfpList);
+    data.append(numberfpList);
 
     return data;
 }
 
 QVector<QStringList> UkuiMenuInterface::getFunctionalClassification()
 {
-    QStringList list[11];
+    QVector<QStringList> appVector[11];
     int index=0;
     while(index<appInfoVector.size())
     {
@@ -565,35 +639,38 @@ QVector<QStringList> UkuiMenuInterface::getFunctionalClassification()
         {
             int category=appInfoVector.at(index).at(5+i).toInt();
             switch (category) {
+            case 0:
+                appVector[0].append(appInfoVector.at(index));
+                break;
             case 1:
-                list[1].append(appInfoVector.at(index).at(2));
+                appVector[1].append(appInfoVector.at(index));
                 break;
             case 2:
-                list[3].append(appInfoVector.at(index).at(2));
+                appVector[2].append(appInfoVector.at(index));
                 break;
             case 3:
-                list[3].append(appInfoVector.at(index).at(2));
+                appVector[3].append(appInfoVector.at(index));
                 break;
             case 4:
-                list[4].append(appInfoVector.at(index).at(2));
+                appVector[4].append(appInfoVector.at(index));
                 break;
             case 5:
-                list[5].append(appInfoVector.at(index).at(2));
+                appVector[5].append(appInfoVector.at(index));
                 break;
             case 6:
-                list[6].append(appInfoVector.at(index).at(2));
+                appVector[6].append(appInfoVector.at(index));
                 break;
             case 7:
-                list[7].append(appInfoVector.at(index).at(2));
+                appVector[7].append(appInfoVector.at(index));
                 break;
             case 8:
-                list[8].append(appInfoVector.at(index).at(2));
+                appVector[8].append(appInfoVector.at(index));
                 break;
             case 9:
-                list[9].append(appInfoVector.at(index).at(2));
+                appVector[9].append(appInfoVector.at(index));
                 break;
             case 10:
-                list[10].append(appInfoVector.at(index).at(2));
+                appVector[10].append(appInfoVector.at(index));
                 break;
             default:
                 break;
@@ -602,39 +679,19 @@ QVector<QStringList> UkuiMenuInterface::getFunctionalClassification()
         index++;
     }
 
-//    QStringList recentList=get_recent_app_list();//最近添加
-//    for(int i=0;i<10;i++)
-//        list[0].append(recentList.at(i));
-
-    QString path=QDir::homePath()+"/.config/ukui/ukui-menu.ini";
-    setting=new QSettings(path,QSettings::IniFormat);
-    setting->beginGroup("recentapp");
-    QStringList keys=setting->allKeys();
-    for(int i=0;i<keys.count();i++)
-    {
-        QString desktopfp=QString("/usr/share/applications/"+keys.at(i));
-        QString appname=getAppName(desktopfp);
-        list[0].append(appname);
-    }
-    setting->endGroup();
-
     QVector<QStringList> data;
+    data.clear();
 
-    QLocale local;
-    QString language=local.languageToString(local.language());
-    if(QString::compare(language,"Chinese")==0)
-        local=QLocale(QLocale::Chinese);
-    else
-        local=QLocale(QLocale::English);
-    QCollator collator(local);
     for(int i=0;i<11;i++)
     {
-        std::sort(list[i].begin(),list[i].end(),collator);
-        data.append(list[i]);
+        QStringList desktopfpList;
+        desktopfpList.clear();
+        qSort(appVector[i].begin(),appVector[i].end(),cmpApp);
+        for(int j=0;j<appVector[i].size();j++)
+            desktopfpList.append(appVector[i].at(j).at(0));
+        data.append(desktopfpList);
     }
-
     return data;
-
 }
 
 bool UkuiMenuInterface::matchingAppCategories(QString desktopfp, QStringList categorylist)
@@ -652,149 +709,90 @@ bool UkuiMenuInterface::matchingAppCategories(QString desktopfp, QStringList cat
     return false;
 }
 
-//应用排序
-QStringList UkuiMenuInterface::sortAppName()
+void UkuiMenuInterface::getAndroidApp()
 {
-    QStringList desktopfpList=getDesktopFilePath();
-    QStringList appnameList;
-    appnameList.clear();
-    for(int i=0;i<desktopfpList.count();i++)
-    {
-        QString appname=getAppName(desktopfpList.at(i));
-        appnameList.append(appname);
+    androidDesktopfnList.clear();
+    QVector<QStringList> androidVector;
+    androidVector.clear();
+    QString path=QDir::homePath()+"/.local/share/applications/";
+    QDir dir(path);
+    if (!dir.exists()) {
+        return;
     }
 
-    //从appnameList中将应用名首字符为非字母的移除
-    QStringList otherappname;//不是26个字母开头
-    QStringList numberappname;//以数字开头
-    otherappname.clear();
-    numberappname.clear();
-    for(int i=0;i<appnameList.count();i++)
-    {
-        QString appname=UkuiChineseLetter::getPinyins(appnameList.at(i));
-        QChar c=appname.at(0);
-        if( c<48 || (c>57 && c<65) || c>90 )
-        {
-            otherappname.append(appnameList.at(i));
-            appnameList.removeAt(i);
-            i--;
-
-        }
-
-        if(c>=48 && c<=57)
-        {
-            numberappname.append(appnameList.at(i));
-            appnameList.removeAt(i);
-            i--;
-        }
-
-
+    dir.setFilter(QDir::Dirs|QDir::Files|QDir::NoDotAndDotDot);
+    dir.setSorting(QDir::DirsFirst);
+    QFileInfoList list = dir.entryInfoList();
+    if(list.size()< 1 ) {
+        return;
     }
+    int i=0;
 
+    GError** error=nullptr;
+    GKeyFileFlags flags=G_KEY_FILE_NONE;
+    GKeyFile* keyfile=g_key_file_new ();
 
-    //判断语言环境
-    QLocale cn;
-    QString language=cn.languageToString(cn.language());
-    if(QString::compare(language,"Chinese")==0)
-    {
-//        //中文环境
-//        //执行sort后，appnameList前半部分为已按字母排序好的中文，后半部分为英文
-//        QLocale cn(QLocale::Chinese);
-//        QCollator collator(cn);
-//        std::sort(appnameList.begin(), appnameList.end(), collator);
+    do{
+        QFileInfo fileInfo = list.at(i);
+        if(!fileInfo.isFile())
+        {
+            i++;
+            continue;
+        }
+        //过滤后缀不是.desktop的文件
+        QString filePathStr=fileInfo.filePath();
+        if(!filePathStr.endsWith(".desktop"))
+        {
+            i++;
+            continue;
+        }
 
-//        //找到appnameList中第一个首字母为英文的应用名，记住位置为index
-//        int index=0;
-//        for(int i=0;i<appnameList.count();i++)
-//        {
-//            QString appnamestr=appnameList.at(i);
-//            QChar c=appnamestr.at(0);
-//            if((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') )
-//            {
-//                index=i;
-//                break;
-//            }
-//        }
-
-//        //将应用名首字母为非英文的插入到已排序好的中文序列中
-//        while(index<appnameList.count())
-//        {
-//            int i=0;
-//            for(i=0;i<index;i++)
-//            {
-//                QString indexstr=appnameList.at(index);
-//                QString letter=ChineseLetterHelper::GetPinyins(appnameList.at(i));
-//                QString indexletter=ChineseLetterHelper::GetPinyins(indexstr);
-//                if(QString::compare(letter,indexletter)>0)
-//                {
-//                    appnameList.removeAt(index);
-//                    appnameList.insert(i,indexstr);
-//                    index++;
-//                    break;
-//                }
-//            }
-//            if(i==index)index++;
-
-//        }
-//选择排序法
-//        int index=0;
-//        while(index<appnameList.count())
-//        {
-//            int min=index;
-//            QString indexstr=ChineseLetterHelper::GetPinyins(appnameList.at(index));
-//            int i;
-//            for(i=index;i<appnameList.count();i++)
-//            {
-//                QString appname=ChineseLetterHelper::GetPinyins(appnameList.at(i));
-//                if(QString ::compare(appname,indexstr)<0)
-//                {
-//                    indexstr=appname;
-//                    min=i;
-//                }
-//            }
-
-
-//            QString tmp=appnameList.at(min);
-//            appnameList.removeAt(min);
-//            appnameList.insert(index,tmp);
-//            index++;
-//        }
-
-//起泡排序法
-        for(int i=0;i<appnameList.count()-1;i++)
-            for(int j=0;j<appnameList.count()-1-i;j++)
+        QByteArray fpbyte=filePathStr.toLocal8Bit();
+        char* filepath=fpbyte.data();
+        g_key_file_load_from_file(keyfile,filepath,flags,error);
+        char* ret_1=g_key_file_get_locale_string(keyfile,"Desktop Entry","Categories", nullptr, nullptr);
+        if(ret_1!=nullptr)
+        {
+            QString str=QString::fromLocal8Bit(ret_1);
+            if(!str.contains("Android"))
             {
-                QString appname_1=UkuiChineseLetter::getPinyins(appnameList.at(j));
-                QString appname_2=UkuiChineseLetter::getPinyins(appnameList.at(j+1));
-                if(QString::compare(appname_1,appname_2)>0)
-                {
-                    QString tmp=appnameList.at(j);
-                    appnameList.replace(j,appnameList.at(j+1));
-                    appnameList.replace(j+1,tmp);
-
-                }
+                i++;
+                continue;
             }
+            else
+            {
+                filePathList.append(filePathStr);
+                androidDesktopfnList.append(fileInfo.fileName());
+            }
+        }
 
-    }
-    else{
-        //英文环境
-        QLocale cn(QLocale::English);
-        QCollator collator(cn);
-        std::sort(appnameList.begin(), appnameList.end(), collator);
-    }
+        i++;
+    }while(i < list.size());
 
-    for(int i=0;i<otherappname.count();i++)
+    g_key_file_free(keyfile);
+}
+
+QString UkuiMenuInterface::getAppNameInitials(QString desktopfp)
+{
+    QString firstLetters;
+    QString appname=getAppName(desktopfp);
+    QStringList appnamestr=appname.split(" ");
+    QString letters;
+    Q_FOREACH(QString name,appnamestr)
     {
-        appnameList.append(otherappname.at(i));
+        letters.clear();
+        letters=UkuiChineseLetter::getFirstLettersAll(name);
+        if(letters.isEmpty())
+            letters=UkuiChineseLetter::getFirstLetter(name);
+        firstLetters.append(letters);
     }
 
-    for(int i=0;i<numberappname.count();i++)
-    {
-        appnameList.append(numberappname.at(i));
-    }
+    return firstLetters;
+}
 
-//    qDebug()<<appnameList.count();
-    return appnameList;
+QString UkuiMenuInterface::getAppNameInitial(QString desktopfp)
+{
+    return UkuiChineseLetter::getFirstLetter(getAppName(desktopfp));
 }
 
 //获取应用拼音
@@ -826,7 +824,6 @@ QStringList UkuiMenuInterface::getSpecifiedCategoryAppList(QString categorystr)
                 {
                     QString appname=getAppName(desktopfpList.at(index));
                     if(QString::compare(appname,"访问提示")==0)
-//                        qDebug()<<desktopfpList.at(index);
                     appnameList.append(appname);
                     break;
                 }
@@ -860,7 +857,6 @@ QString UkuiMenuInterface::getUserIcon()
 QString UkuiMenuInterface::getUserName()
 {
     qint64 uid=static_cast<qint64>(getuid());
-//    QString name=QDir::homePath();
     QDBusInterface iface("org.freedesktop.Accounts",
                          "/org/freedesktop/Accounts",
                          "org.freedesktop.Accounts",
