@@ -31,17 +31,25 @@ public:
     void run();
 
 private:
-    QString keyword;
-    QStringList searchResultList;
+    QString m_keyWord;
+    QVector<QStringList> m_searchResultVector;
 
-    UkuiMenuInterface* pUkuiMenuInterface=nullptr;
-    QVector<QStringList> appInfoVector;
+    UkuiMenuInterface* m_ukuiMenuInterface=nullptr;
+    QVector<QStringList> m_appInfoVector;
 
-private Q_SLOTS:
+public Q_SLOTS:
+    /**
+     * @brief Receive search keywords
+     * @param arg: Search keywords
+     */
     void recvSearchKeyword(QString arg);
 
 Q_SIGNALS:
-    void sendSearchResult(QStringList list);
+    /**
+     * @brief Send search results
+     * @param vector: Search results
+     */
+    void sendSearchResult(QVector<QStringList> vector);
 
 };
 
