@@ -26,6 +26,8 @@
 #include "src/Style/style.h"
 #include "src/RightClickMenu/rightclickmenu.h"
 #include <QSettings>
+#include <QEvent>
+#include <QKeyEvent>
 #include "src/Interface/ukuimenuinterface.h"
 #include "itemdelegate.h"
 
@@ -59,14 +61,10 @@ private:
 private Q_SLOTS:
     void onClicked(QModelIndex index);//点击item
     void rightClickedSlot();//右键菜单
-
 Q_SIGNALS:
-    void sendItemClickedSignal(QStringList arg);//向字母排序或功能分类模块发送item点击信号
-    void sendFixedOrUnfixedSignal(QString desktopfp,int type);//向字母排序、功能分类发送固定或者取消固定信号
-    void sendUpdateAppListSignal(QString desktopfp,int type);//向CommonUseWidget发送更新应用列表信号
-    void removeListItemSignal(QString desktopfp);
-    void removeListAllItemSignal();
+    void sendItemClickedSignal(QStringList arg);//发送item点击信号
     void sendHideMainWindowSignal();
+    void sendUpdateAppListSignal();
 };
 
 #endif // LISTVIEW_H
