@@ -31,6 +31,8 @@ ScrollArea::ScrollArea()
                                              );
       installEventFilter(this);
       this->setFocusPolicy(Qt::NoFocus);
+      this->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+      this->verticalScrollBar()->setContextMenuPolicy(Qt::NoContextMenu);
 }
 
 void ScrollArea::enterEvent(QEvent *e)
