@@ -22,6 +22,8 @@
 #include <QEvent>
 #include <QScrollBar>
 #include <QMouseEvent>
+#include <QMouseEvent>
+#include <QPropertyAnimation>
 
 class ScrollArea : public QScrollArea
 {
@@ -32,6 +34,9 @@ protected:
     void enterEvent(QEvent* e) Q_DECL_OVERRIDE;
     void leaveEvent(QEvent* e) Q_DECL_OVERRIDE;
 
+private:
+    double m_speedTime = 3;
+
 };
 
 #endif // SCROLLAREA_H
